Stan Math Library: stan/math/prim/scal/prob/bernoulli_logit_log.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
bernoulli_logit_log.hpp File Reference
`#include <stan/math/prim/scal/meta/is_constant_struct.hpp>`
`#include <stan/math/prim/scal/meta/partials_return_type.hpp>`
`#include <stan/math/prim/scal/meta/OperandsAndPartials.hpp>`
`#include <stan/math/prim/scal/err/check_consistent_sizes.hpp>`
`#include <stan/math/prim/scal/err/check_bounded.hpp>`
`#include <stan/math/prim/scal/err/check_finite.hpp>`
`#include <stan/math/prim/scal/err/check_not_nan.hpp>`
`#include <stan/math/prim/scal/fun/constants.hpp>`
`#include <stan/math/prim/scal/fun/inv_logit.hpp>`
`#include <stan/math/prim/scal/fun/log1m.hpp>`
`#include <stan/math/prim/scal/fun/value_of.hpp>`
`#include <stan/math/prim/scal/meta/include_summand.hpp>`
`#include <boost/random/bernoulli_distribution.hpp>`
`#include <boost/random/variate_generator.hpp>`
`#include <cmath>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<bool propto, typename T_n , typename T_prob >
return_type< T_prob >::type | stan::math::bernoulli_logit_log (const T_n &n, const T_prob &theta)
template<typename T_n , typename T_prob >
return_type< T_prob >::type | stan::math::bernoulli_logit_log (const T_n &n, const T_prob &theta)

[ Stan Home Page ] © 2011–2016, Stan Development Team.